import EventEmitter from 'events';
import * as http from 'http';

declare class Room<TState = unknown> extends EventEmitter {
    id: string;
    type: string;
    clients: string[];
    state: TState;
    config: Record<string, unknown>;
    constructor(id: string, type: string, config: Record<string, unknown>);
    addClient(clientId: string): void;
    removeClient(clientId: string): void;
    updateState(updateFn: (currentState: TState) => TState): void;
}

type RoomConstructor = new (roomId: string, roomType: string, config: object) => Room;
declare class CybercafeServer {
    private io;
    private rooms;
    private roomTypes;
    constructor(server: http.Server);
    joinOrCreateRoom(roomType: string, clientId: string): void;
    define(type: string, constructor: RoomConstructor): void;
    createRoom(roomType: string, config: object): string;
    joinRoom(roomId: string, clientId: string): void;
    leaveRoom(roomId: string, clientId: string): void;
    moveClientToRoom(clientId: string, fromRoomId: string, toRoomId: string): void;
    private generateRoomId;
}

export { CybercafeServer, Room };
