"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  CybercafeServer: () => CybercafeServer,
  Room: () => Room
});
module.exports = __toCommonJS(src_exports);

// src/classes/Room.ts
var import_events = __toESM(require("events"));
var Room = class extends import_events.default {
  id;
  type;
  clients;
  state;
  config;
  constructor(id, type, config) {
    super();
    this.id = id;
    this.type = type;
    this.clients = [];
    this.state = {};
    this.config = { ...config };
  }
  addClient(clientId) {
    this.clients.push(clientId);
  }
  removeClient(clientId) {
    this.clients = this.clients.filter((cid) => cid !== clientId);
  }
  updateState(updateFn) {
    this.state = updateFn(this.state);
    this.emit("stateUpdated", {
      roomId: this.id,
      newState: this.state
    });
  }
};

// src/classes/Server.ts
var import_socket = require("socket.io");
var import_uuid = require("uuid");
var CybercafeServer = class {
  io;
  rooms = {};
  roomTypes = {};
  constructor(server) {
    this.io = new import_socket.Server(server);
    this.io.on("connection", (socket) => {
      socket.on(
        "leaveRoom",
        (roomId) => this.leaveRoom(roomId, socket.id)
      );
      socket.on(
        "joinOrCreateRoom",
        (roomType) => this.joinOrCreateRoom(roomType, socket.id)
      );
      socket.on("joinRoomById", (roomId) => {
        this.joinRoom(roomId, socket.id);
      });
    });
  }
  joinOrCreateRoom(roomType, clientId) {
    const existingRoomId = Object.keys(this.rooms).find(
      (roomId) => this.rooms[roomId]?.type === roomType
    );
    if (existingRoomId) {
      this.joinRoom(existingRoomId, clientId);
    } else {
      const newRoomId = this.createRoom(roomType, {});
      this.joinRoom(newRoomId, clientId);
    }
  }
  define(type, constructor) {
    this.roomTypes[type] = constructor;
  }
  createRoom(roomType, config) {
    const roomId = this.generateRoomId();
    const RoomTypeConstructor = this.roomTypes[roomType];
    if (!RoomTypeConstructor) {
      throw new Error(`Room type ${roomType} is not defined.`);
    }
    const room = new RoomTypeConstructor(roomId, roomType, config);
    room.on("stateUpdated", (event) => {
      this.io.to(event.roomId).emit("stateUpdated", event.newState);
    });
    this.rooms[roomId] = room;
    return roomId;
  }
  joinRoom(roomId, clientId) {
    const room = this.rooms[roomId];
    if (room) {
      room.addClient(clientId);
      this.io.to(clientId).emit("joinedRoom", room);
    }
  }
  leaveRoom(roomId, clientId) {
    const room = this.rooms[roomId];
    room?.removeClient(clientId);
  }
  moveClientToRoom(clientId, fromRoomId, toRoomId) {
    const fromRoom = this.rooms[fromRoomId];
    const toRoom = this.rooms[toRoomId];
    if (!fromRoom) {
      throw new Error(`Room with ID ${fromRoomId} does not exist.`);
    }
    if (!toRoom) {
      throw new Error(`Room with ID ${toRoomId} does not exist.`);
    }
    fromRoom.removeClient(clientId);
    toRoom.addClient(clientId);
  }
  generateRoomId() {
    return "room_" + (0, import_uuid.v4)();
  }
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  CybercafeServer,
  Room
});
